==> phpnuke-5.5.tgz: www/phpnuke/html/modules/Private_Messages/language/lang-english.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please sent to me (fbc@mandrakesoft.com)    */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_EMAIL","Email");
define("_RE","Re");
define("_SUBJECT","Subject");
define("_PRIVATEMESSAGES","Your Private Messages");
define("_CHECKALL","Check All");
define("_FROM","From");
define("_DATE","Date");
define("_DONTHAVEMESSAGES","You don't have any Messages");
define("_NOTREAD","Not Read");
define("_MSGSTATUS","Message Status");
define("_PRIVATEMESSAGE","Private Message");
define("_INDEX","Index");
define("_SENT","Sent");
define("_PREVIOUSMESSAGE","Previous Message");
define("_NEXTMESSAGE","Next Message");
define("_PROFILE","Profile");
define("_ABOUTPOSTING","About Posting");
define("_ALLREGCANPOST","All registered users can post private messages");
define("_TO","To");
define("_MESSAGEICON","Message Icon");
define("_MESSAGE","Message");
define("_HTML","HTML");
define("_PMON","On");
define("_PMOFF","Off");
define("_BBCODE","BBCode");
define("_WROTE","wrote");
define("_OPTIONS","Options");
define("_HTMLDISSABLE","Disable HTML on this Post");
define("_BBCODEDISSABLE","Disable <i>BBCode</i> on this Post");
define("_SMILEDISSABLE","Disable <i>Smilies</i> on this Post");
define("_CANCELREPLY","Cancel Reply");
define("_CANCELSEND","Cancel Send");
define("_CLEAR","Clear");
define("_SUBMIT","Submit");
define("_USERNOTINDB","The selected user doesn't exist in the database.");
define("_CHECKNAMEANDTRY","Please check the name and try again.");
define("_MSGPOSTED","Your Message has been Posted.");
define("_RETURNTOPMSG","You can click here to reload your private messages.");
define("_MSGDELETED","Your Messages has been Deleted.");
define("_BBGO","go");
define("_BBNEWPMSG","New Messages");
define("_BBNONEWPMSG","No New Messages");
define("_BBTOTALPMSG","Total Messages");
define("_BBEMPTYPMSG","You don't have any Messages");
define("_BBLOGIN","Login to check your private message");
define("_BBPMSG","Private Message");
define("_BBINBOX","Inbox");
define("_BBSELECTFORUM","Select a Forum");
define("_BBNOFORUM","No More Forum");
define("_BBBANNED","Banned");
define("_CLICKSMILEBUTTONS","Click on the Smilies to insert it on your Message:");
define("_CLICKCODEBUTTONS","Click on the following buttons to add BBCode to your Message:");
define("_PRIVMSGERROR","Private Message Error!");
define("_USERDOESNTEXIST","Sorry, the selected user doesn't exist in our database")

?>

==> phpnuke-5.6.tgz: www/phpnuke/html/modules/Private_Messages/language/lang-english.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please go to the site and send to me        */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_EMAIL","Email");
define("_RE","Re");
define("_SUBJECT","Subject");
define("_PRIVATEMESSAGES","Your Private Messages");
define("_CHECKALL","Check All");
define("_FROM","From");
define("_DATE","Date");
define("_DONTHAVEMESSAGES","You don't have any Messages");
define("_NOTREAD","Not Read");
define("_MSGSTATUS","Message Status");
define("_PRIVATEMESSAGE","Private Message");
define("_INDEX","Index");
define("_SENT","Sent");
define("_PREVIOUSMESSAGE","Previous Message");
define("_NEXTMESSAGE","Next Message");
define("_PROFILE","Profile");
define("_ABOUTPOSTING","About Posting");
define("_ALLREGCANPOST","All registered users can post private messages");
define("_TO","To");
define("_MESSAGEICON","Message Icon");
define("_MESSAGE","Message");
define("_HTML","HTML");
define("_PMON","On");
define("_PMOFF","Off");
define("_BBCODE","BBCode");
define("_WROTE","wrote");
define("_OPTIONS","Options");
define("_HTMLDISSABLE","Disable HTML on this Post");
define("_BBCODEDISSABLE","Disable <i>BBCode</i> on this Post");
define("_SMILEDISSABLE","Disable <i>Smilies</i> on this Post");
define("_CANCELREPLY","Cancel Reply");
define("_CANCELSEND","Cancel Send");
define("_CLEAR","Clear");
define("_SUBMIT","Submit");
define("_USERNOTINDB","The selected user doesn't exist in the database.");
define("_CHECKNAMEANDTRY","Please check the name and try again.");
define("_MSGPOSTED","Your Message has been Posted.");
define("_RETURNTOPMSG","You can click here to reload your private messages.");
define("_MSGDELETED","Your Messages has been Deleted.");
define("_BBGO","go");
define("_BBNEWPMSG","New Messages");
define("_BBNONEWPMSG","No New Messages");
define("_BBTOTALPMSG","Total Messages");
define("_BBEMPTYPMSG","You don't have any Messages");
define("_BBLOGIN","Login to check your private message");
define("_BBPMSG","Private Message");
define("_BBINBOX","Inbox");
define("_BBSELECTFORUM","Select a Forum");
define("_BBNOFORUM","No More Forum");
define("_BBBANNED","Banned");
define("_CLICKSMILEBUTTONS","Click on the Smilies to insert it on your Message:");
define("_CLICKCODEBUTTONS","Click on the following buttons to add BBCode to your Message:");
define("_PRIVMSGERROR","Private Message Error!");
define("_USERDOESNTEXIST","Sorry, the selected user doesn't exist in our database")

?>
